/*
   This sketch read arcade buttons the Adafruit Arcade QT and controls a relay module
*/

#include "Adafruit_seesaw.h"
#include <seesaw_neopixel.h>
#include <Wire.h>

#include <RelayModule.h>

#define  DEFAULT_I2C_ADDR 0x3A

#define  SWITCH1  18  // PA01
#define  SWITCH2  19 // PA02
#define  SWITCH3  20 // PA03
#define  SWITCH4  2 // PA06
#define  PWM1  12  // PC00
#define  PWM2  13 // PC01
#define  PWM3  0 // PA04
#define  PWM4  1 // PA05

#define PIN_RELAY_1  8 // the Arduino pin, which connects to the IN1 pin of relay module
#define PIN_RELAY_2  7 // the Arduino pin, which connects to the IN2 pin of relay module
#define PIN_RELAY_3  6 // the Arduino pin, which connects to the IN3 pin of relay module
#define PIN_RELAY_4  5 // the Arduino pin, which connects to the IN4 pin of relay module
#define DELAY_TIME  1000
#define INVERT_RELAY true

Adafruit_seesaw ss;

int state1;
int state2;
int state3;
int state4;

RelayModule* relay1 = NULL;
RelayModule* relay2 = NULL;
RelayModule* relay3 = NULL;
RelayModule* relay4 = NULL;

void setup() {

  Wire.begin();
  Serial.begin(115200);

  while (!Serial) delay(10);   // wait until serial port is opened

  Serial.println(F("Adafruit PID 5296 I2C QT 4x LED Arcade Buttons test!"));

  if (!ss.begin(DEFAULT_I2C_ADDR)) {
    Serial.println(F("Arcade buttons not found "));
    while (1) delay(10);
  }

  uint16_t pid;
  uint8_t year, mon, day;

  ss.getProdDatecode(&pid, &year, &mon, &day);
  Serial.print("seesaw found PID: ");
  Serial.print(pid);
  Serial.print(" datecode: ");
  Serial.print(2000 + year); Serial.print("/");
  Serial.print(mon); Serial.print("/");
  Serial.println(day);

  if (pid != 5296) {
    Serial.println(F("Wrong seesaw PID"));
    while (1) delay(10);
  }

  Serial.println(F("seesaw started OK!"));
  ss.pinMode(SWITCH1, INPUT_PULLUP);
  ss.pinMode(SWITCH2, INPUT_PULLUP);
  ss.pinMode(SWITCH3, INPUT_PULLUP);
  ss.pinMode(SWITCH4, INPUT_PULLUP);
  ss.analogWrite(PWM1, 0);
  ss.analogWrite(PWM2, 0);
  ss.analogWrite(PWM3, 0);
  ss.analogWrite(PWM4, 0);

  relay1 = new RelayModule(PIN_RELAY_1, INVERT_RELAY);
  relay2 = new RelayModule(PIN_RELAY_2, INVERT_RELAY);
  relay3 = new RelayModule(PIN_RELAY_3, INVERT_RELAY);
  relay4 = new RelayModule(PIN_RELAY_4, INVERT_RELAY);

  Serial.println("Lets test the relays,");

  Serial.println("Turn off all");
  relay1->off(); // turn the relay off.
  relay2->off(); // turn the relay off.
  relay3->off(); // turn the relay off.
  relay4->off(); // turn the relay off.
  delay(1000);


}

uint8_t incr = 0;

void loop() {

  if (! ss.digitalRead(SWITCH1)) {
    Serial.println("Switch 1 pressed");

    if (relay1->isOn()) {
      relay1->off(); // turn the relay off.
      ss.analogWrite(PWM1, 0);
    } else if (relay1->isOff()) {
      relay1->on(); // turn the relay on.
      ss.analogWrite(PWM1, 125);
    }

    delay(DELAY_TIME); // wait for a delay time.
  }

  if (! ss.digitalRead(SWITCH2)) {
    Serial.println("Switch 2 pressed");

    if (relay2->isOn()) {
      relay2->off(); // turn the relay off.
      ss.analogWrite(PWM2, 0);
    } else if (relay2->isOff()) {
      relay2->on(); // turn the relay on.
      ss.analogWrite(PWM2, 125);
    }

    delay(DELAY_TIME); // wait for a delay time.
  }

  if (! ss.digitalRead(SWITCH3)) {
    Serial.println("Switch 3 pressed");

    if (relay3->isOn()) {
      relay3->off(); // turn the relay off.
      ss.analogWrite(PWM3, 0);
    } else if (relay3->isOff()) {
      relay3->on(); // turn the relay on.
      ss.analogWrite(PWM3, 125);
    }

    delay(DELAY_TIME); // wait for a delay time.
  }

  if (! ss.digitalRead(SWITCH4)) {
    Serial.println("Switch 4 pressed");

    if (relay4->isOn()) {
      relay4->off(); // turn the relay off.
      ss.analogWrite(PWM4, 0);
    } else if (relay4->isOff()) {
      relay4->on(); // turn the relay on.
      ss.analogWrite(PWM4, 125);
    }

    delay(DELAY_TIME); // wait for a delay time.
  }

  delay(1000);
}
